@@ -26,7 +26,7 @@
 #include "FileType.h"
 #include "transcoding/TranscodingJob.h"
 
-#include <KIO/CopyJob>
+#include <KIO/FileCopyJob>
 #include <KIO/Job>
 #include <KMessageBox>
 
@@ -118,7 +118,7 @@ IpodCopyTracksJob::run(ThreadWeaver::JobPointer self, ThreadWeaver::Thread *thre
         /* determine destination filename; we cannot use ipodTrack because as it has no itdb
          * (and thus mountpoint) set */
         GError *error = nullptr;
-        gchar *destFilename = itdb_cp_get_dest_filename( nullptr, mountPoint, fakeSrcName, &error );
+        gchar *destFilename = itdb_cp_get_dest_filename( nullptr, mountPoint.constData(), fakeSrcName.constData(), &error );
         if( error )
         {
             warning() << "Cannot construct iPod track filename:" << error->message;
@@ -173,7 +173,7 @@ IpodCopyTracksJob::run(ThreadWeaver::JobPointer self, ThreadWeaver::Thread *thre
         // create a new track object by copying meta-data from existing one:
         IpodMeta::Track *ipodTrack = new IpodMeta::Track( track );
         // tell the track it has been copied:
-        bool accepted = ipodTrack->finalizeCopying( mountPoint, destFilename );
+        bool accepted = ipodTrack->finalizeCopying( mountPoint.constData(), destFilename );
         g_free( destFilename );
         destFilename = nullptr;
         if( !accepted )
@@ -321,7 +321,7 @@ IpodCopyTracksJob::slotStartCopyOrTranscodeJob( const QUrl &sourceUrlOrig, const
     QUrl sourceUrl( sourceUrlOrig );
     // KIO::file_copy in KF5 needs scheme
     if (sourceUrl.isRelative() && sourceUrl.host().isEmpty()) {
-        sourceUrl.setScheme("file");
+        sourceUrl.setScheme(QStringLiteral("file"));
     }
 
     KJob *job = nullptr;
@@ -386,7 +386,7 @@ IpodCopyTracksJob::slotDisplayErrorDialog()
                           exceededingSafeCapacityCount );
 
         QString reservedSpace = m_coll ? QLocale().toString(
-            m_coll->capacityMargin(), 1 ) : QString( "???" ); // improbable, don't bother translators
+            m_coll->capacityMargin(), 1 ) : QStringLiteral( "???" ); // improbable, don't bother translators
 
         details += i18nc( "Example of %1 would be: 20.0 MiB",
                           "<i>Amarok reserves %1 on iPod for iTunes database writing.</i><br>",
@@ -395,7 +395,7 @@ IpodCopyTracksJob::slotDisplayErrorDialog()
     int notPlayableCount = m_sourceTrackStatus.count( NotPlayable );
     if( notPlayableCount )
     {
-        QString formats = QStringList( m_notPlayableFormats.values() ).join( ", " );
+        QString formats = QStringList( m_notPlayableFormats.values() ).join( QStringLiteral(", ") );
         details += i18np( "One track was not copied because it wouldn't be playable - its "
                           " %2 format is unsupported.<br>",
                           "%1 tracks were not copied because they wouldn't be playable - "
@@ -424,7 +424,7 @@ IpodCopyTracksJob::slotDisplayErrorDialog()
     if( !m_copyErrors.isEmpty() )
     {
         details += i18nc( "%1 is a list of errors that occurred during copying of tracks",
-                          "Error causes: %1<br>", QStringList( m_copyErrors.values() ).join( "<br>" ) );
+                          "Error causes: %1<br>", QStringList( m_copyErrors.values() ).join( QStringLiteral("<br>") ) );
     }
     KMessageBox::detailedError( nullptr, text, details, caption );
 }
