@@ -26,32 +26,30 @@ namespace Playlists
 
     class MediaDevicePlaylist;
 
-    typedef KSharedPtr<MediaDevicePlaylist> MediaDevicePlaylistPtr;
+    typedef AmarokSharedPointer<MediaDevicePlaylist> MediaDevicePlaylistPtr;
     typedef QList<MediaDevicePlaylistPtr> MediaDevicePlaylistList;
 
     class MediaDevicePlaylist : public Playlist
     {
         public:
             MediaDevicePlaylist( const QString &name, const Meta::TrackList &tracks );
-            ~MediaDevicePlaylist();
+            ~MediaDevicePlaylist() override;
 
             // Playlist Functions
-            virtual QString name() const { return m_name; }
-            virtual QString description() const { return QString(); }
-            virtual KUrl uidUrl() const { return KUrl(); }
+            QString name() const override { return m_name; }
+            QUrl uidUrl() const override { return QUrl(); }
 
             /**override showing just the filename */
-            virtual void setName( const QString &name );
+            void setName( const QString &name ) override;
 
-            /** returns all tracks in this playlist */
-            virtual Meta::TrackList tracks();
-            virtual void addTrack( Meta::TrackPtr track, int position = -1 );
+            int trackCount() const override;
+            Meta::TrackList tracks() override;
+            void addTrack( const Meta::TrackPtr &track, int position = -1 ) override;
 
-            virtual void removeTrack( int position );
+            void removeTrack( int position ) override;
 
     private:
         Meta::TrackList m_tracks;
-        QString m_description;
         QString m_name;
 
     };
