@@ -53,7 +53,7 @@ ITunesTrack::lastPlayed() const
 
     QDateTime date = QDateTime::fromString(
                                 m_statistics.value( Meta::valLastPlayed ).toString(),
-                                "yyyy'-'MM'-'dd'T'hh':'mm':'ss'Z'" );
+                                QStringLiteral("yyyy'-'MM'-'dd'T'hh':'mm':'ss'Z'") );
     if( date.isValid() )
         date.setTimeSpec( Qt::UTC );
 
