@@ -29,12 +29,10 @@
 #include "SvgHandler.h"
 #include "amarokconfig.h"
 #include "AmarokMimeData.h"
-#include "core/capabilities/ReadLabelCapability.h"
 #include "core/support/Debug.h"
 #include "EngineController.h"
 #include "core/capabilities/MultiSourceCapability.h"
 #include "core/capabilities/SourceInfoCapability.h"
-#include "core/collections/Collection.h"
 #include "core/meta/Statistics.h"
 #include "core/meta/support/MetaUtility.h"
 #include "PlaylistDefines.h"
@@ -48,9 +46,7 @@
 #include <KLocalizedString>
 #include <KIconLoader>
 
-#include <QAction>
 #include <QTimer>
-#include <QDate>
 #include <QStringList>
 #include <QUrl>
 
@@ -77,9 +73,9 @@ breakLongLinesHTML( const QString &origText )
 {
     // filter-out HTML tags..
     QString text( origText );
-    text.replace( '&', QLatin1String("&amp;") ); // needs to be first, obviously
-    text.replace( '<', QLatin1String("&lt;") );
-    text.replace( '>', QLatin1String("&gt;") );
+    text.replace( QLatin1Char('&'), QLatin1String("&amp;") ); // needs to be first, obviously
+    text.replace( QLatin1Char('<'), QLatin1String("&lt;") );
+    text.replace( QLatin1Char('>'), QLatin1String("&gt;") );
 
     // Now let's break up long lines so that the tooltip doesn't become hideously large
     if( fitsInOneLineHTML( text ) )
@@ -90,7 +86,7 @@ breakLongLinesHTML( const QString &origText )
         const int lnSize = TOOLTIP_STATIC_LINEBREAK;
         QString textInLines;
 
-        QStringList words = text.trimmed().split(' ');
+        QStringList words = text.trimmed().split(QLatin1Char(' '));
         int lineLength = 0;
         while(words.size() > 0)
         {
@@ -110,10 +106,10 @@ breakLongLinesHTML( const QString &origText )
                     QString wordPart = word;
                     wordPart.resize(lnSize);
                     word.remove(0,lnSize);
-                    textInLines += wordPart + "<br/>";
+                    textInLines += wordPart + QStringLiteral("<br/>");
                 }
             }
-            textInLines += word + ' ';
+            textInLines += word + QLatin1Char(' ');
             lineLength += word.size() + 1;
             words.removeFirst();
         }
@@ -136,7 +132,7 @@ HTMLLine( const Playlist::Column& column, const QString& value, bool force = fal
     {
         QString line;
         line += QLatin1String("<tr><td align=\"right\">");
-        line += "<img src=\""+KIconLoader::global()->iconPath( Playlist::iconName( column ), -16)+"\" />";
+        line += QStringLiteral("<img src=\"")+KIconLoader::global()->iconPath( Playlist::iconName( column ), -16)+QStringLiteral("\" />");
         line += QLatin1String("</td><td align=\"left\">");
         line += breakLongLinesHTML( value );
         line += QLatin1String("</td></tr>");
@@ -311,7 +307,7 @@ Playlist::Model::tooltipFor( Meta::TrackPtr track ) const
     if( s_tooltipColumns[Playlist::Labels] && !track->labels().empty() )
     {
         QStringList labels;
-        foreach( Meta::LabelPtr label, track->labels() )
+        for( Meta::LabelPtr label : track->labels() )
         {
             if( label )
                 labels << label->name();
@@ -337,7 +333,7 @@ Playlist::Model::tooltipFor( Meta::TrackPtr track ) const
     if( text.isEmpty() )
         text = i18n( "No extra information available" );
     else
-        text = QString("<table>"+ text +"</table>");
+        text = QStringLiteral("<table>") + text + QStringLiteral("</table>");
 
     return text;
 }
@@ -485,7 +481,7 @@ Playlist::Model::data( const QModelIndex& index, int role ) const
                 if( track )
                 {
                     QStringList labelNames;
-                    foreach( const Meta::LabelPtr &label, track->labels() )
+                    for( const Meta::LabelPtr &label : track->labels() )
                     {
                         labelNames << label->prettyName();
                     }
@@ -571,7 +567,7 @@ Playlist::Model::data( const QModelIndex& index, int role ) const
                 if( track->trackNumber() > 0 )
                 {
                     QString trackNumber = QString::number( track->trackNumber() );
-                    trackString =  QString( trackNumber + " - " + trackName );
+                    trackString =  QString( trackNumber + QStringLiteral(" - ") + trackName );
                 } else
                     trackString = trackName;
 
@@ -632,8 +628,8 @@ Playlist::Model::mimeData( const QModelIndexList &indexes ) const
     AmarokMimeData* mime = new AmarokMimeData();
     Meta::TrackList selectedTracks;
 
-    foreach( const QModelIndex &it, indexes )
-    selectedTracks << m_items.at( it.row() )->track();
+    for( const QModelIndex &it : indexes )
+        selectedTracks << m_items.at( it.row() )->track();
 
     mime->setTracks( selectedTracks );
     return mime;
@@ -682,7 +678,7 @@ Playlist::Model::dropMimeData( const QMimeData* data, Qt::DropAction action, int
         if( dragList )
         {
             Meta::TrackList tracks;
-            foreach( Podcasts::PodcastEpisodePtr episode, dragList->podcastEpisodes() )
+            for( Podcasts::PodcastEpisodePtr episode : dragList->podcastEpisodes() )
                 tracks << Meta::TrackPtr::staticCast( episode );
             The::playlistController()->insertTracks( beginRow, tracks );
         }
@@ -695,8 +691,8 @@ Playlist::Model::dropMimeData( const QMimeData* data, Qt::DropAction action, int
         if( dragList )
         {
             Meta::TrackList tracks;
-            foreach( Podcasts::PodcastChannelPtr channel, dragList->podcastChannels() )
-                foreach( Podcasts::PodcastEpisodePtr episode, channel->episodes() )
+            for( Podcasts::PodcastChannelPtr channel : dragList->podcastChannels() )
+                for( Podcasts::PodcastEpisodePtr episode : channel->episodes() )
                     tracks << Meta::TrackPtr::staticCast( episode );
             The::playlistController()->insertTracks( beginRow, tracks );
         }
@@ -756,7 +752,7 @@ Playlist::Model::stateOfRow( int row ) const
 bool
 Playlist::Model::containsTrack( const Meta::TrackPtr& track ) const
 {
-    foreach( Item* i, m_items )
+    for( Item* i : m_items )
     {
         if ( *i->track() == *track )
             return true;
@@ -768,7 +764,7 @@ int
 Playlist::Model::firstRowForTrack( const Meta::TrackPtr& track ) const
 {
     int row = 0;
-    foreach( Item* i, m_items )
+    for( Item* i : m_items )
     {
         if ( *i->track() == *track )
             return row;
@@ -783,7 +779,7 @@ Playlist::Model::allRowsForTrack( const Meta::TrackPtr& track ) const
     QSet<int> trackRows;
 
     int row = 0;
-    foreach( Item* i, m_items )
+    for( Item* i : m_items )
     {
         if ( *i->track() == *track )
             trackRows.insert( row );
@@ -858,7 +854,7 @@ void
 Playlist::Model::metadataChanged(const Meta::TrackPtr &track )
 {
     int row = 0;
-    foreach( Item* i, m_items )
+    for( Item* i : m_items )
     {
         if ( i->track() == track )
         {
@@ -903,7 +899,7 @@ Playlist::Model::exportPlaylist( const QString &path, bool relative )
     // check queue state
     QQueue<quint64> queueIds = The::playlistActions()->queue();
     QList<int> queued;
-    foreach( quint64 id, queueIds ) {
+    for( quint64 id : queueIds ) {
       queued << rowForId( id );
     }
     return Playlists::exportPlaylistFile( tracks(), QUrl::fromLocalFile(path), relative, queued);
@@ -913,7 +909,7 @@ Meta::TrackList
 Playlist::Model::tracks()
 {
     Meta::TrackList tl;
-    foreach( Item* item, m_items )
+    for( Item* item : m_items )
         tl << item->track();
     return tl;
 }
@@ -968,7 +964,7 @@ Playlist::Model::insertTracksCommand( const InsertCmdList& cmds )
     int min = m_items.size() + cmds.size();
     int max = 0;
     int begin = cmds.at( 0 ).second;
-    foreach( const InsertCmd &ic, cmds )
+    for( const InsertCmd &ic : cmds )
     {
         min = qMin( min, ic.second );
         max = qMax( max, ic.second );
@@ -977,7 +973,7 @@ Playlist::Model::insertTracksCommand( const InsertCmdList& cmds )
 
     // actually do the insertion
     beginInsertRows( QModelIndex(), min, max );
-    foreach( const InsertCmd &ic, cmds )
+    for( const InsertCmd &ic : cmds )
     {
         Meta::TrackPtr track = ic.first;
         m_totalLength += track->length();
@@ -1038,7 +1034,7 @@ Playlist::Model::removeTracksCommand( const RemoveCmdList &passedCmds )
     if( m_activeRow >= 0 )
     {
         int activeShift = 0;
-        foreach( const RemoveCmd &rc, cmds )
+        for( const RemoveCmd &rc : cmds )
         {
             if( rc.second < m_activeRow )
                 activeShift++;
@@ -1092,7 +1088,7 @@ Playlist::Model::removeTracksCommand( const RemoveCmdList &passedCmds )
     }
 
     // unsubscribe from tracks no longer present in playlist
-    foreach( Meta::TrackPtr track, trackUnsubscribeCandidates )
+    for( Meta::TrackPtr track : trackUnsubscribeCandidates )
     {
         if( !containsTrack( track ) )
             unsubscribeFrom( track );
@@ -1100,13 +1096,13 @@ Playlist::Model::removeTracksCommand( const RemoveCmdList &passedCmds )
 
     // unsubscribe from albums no longer present im playlist
     QSet<Meta::AlbumPtr> remainingAlbums;
-    foreach( const Item *item, m_items )
+    for( const Item *item : m_items )
     {
         Meta::AlbumPtr album = item->track()->album();
         if( album )
             remainingAlbums.insert( album );
     }
-    foreach( Meta::AlbumPtr album, albumUnsubscribeCandidates )
+    for( Meta::AlbumPtr album : albumUnsubscribeCandidates )
     {
         if( !remainingAlbums.contains( album ) )
             unsubscribeFrom( album );
@@ -1155,7 +1151,7 @@ Playlist::Model::moveTracksCommand( const MoveCmdList& cmds, bool reverse )
 
     int min = INT_MAX;
     int max = INT_MIN;
-    foreach( const MoveCmd &rc, cmds )
+    for( const MoveCmd &rc : cmds )
     {
         min = qMin( min, rc.first );
         max = qMax( max, rc.first );
@@ -1171,7 +1167,7 @@ Playlist::Model::moveTracksCommand( const MoveCmdList& cmds, bool reverse )
     QList<Item*> oldItems( m_items );
     if ( reverse )
     {
-        foreach( const MoveCmd &mc, cmds )
+        for( const MoveCmd &mc : cmds )
         {
             m_items[mc.first] = oldItems.at( mc.second );
             if ( m_activeRow == mc.second )
@@ -1180,7 +1176,7 @@ Playlist::Model::moveTracksCommand( const MoveCmdList& cmds, bool reverse )
     }
     else
     {
-        foreach( const MoveCmd &mc, cmds )
+        for( const MoveCmd &mc : cmds )
         {
             m_items[mc.second] = oldItems.at( mc.first );
             if ( m_activeRow == mc.first )
