@@ -22,6 +22,8 @@
 #include "core-impl/playlists/providers/user/UserPlaylistProvider.h"
 #include "core-impl/playlists/types/file/PlaylistFileSupport.h"
 
+#include <KConfigGroup>
+
 class QTimer;
 
 namespace Playlists {
@@ -34,15 +36,15 @@ class PlaylistFileProvider : public Playlists::UserPlaylistProvider
 
     public:
         PlaylistFileProvider();
-        virtual ~PlaylistFileProvider();
+        ~PlaylistFileProvider() override;
 
-        virtual QString prettyName() const;
-        virtual KIcon icon() const;
+        QString prettyName() const override;
+        QIcon icon() const override;
 
-        virtual int category() const { return Playlists::UserPlaylist; }
+        int category() const override { return Playlists::UserPlaylist; }
 
-        virtual int playlistCount() const;
-        virtual Playlists::PlaylistList playlists();
+        int playlistCount() const override;
+        Playlists::PlaylistList playlists() override;
 
         /**
         * Returns a Playlists::PlaylistPtr to the new playlist, NULL if something failed.
@@ -50,14 +52,14 @@ class PlaylistFileProvider : public Playlists::UserPlaylistProvider
         * @param name File name of the new playlist. If no extension is being given we
         *             default to xspf. '/' and '\' are being replaced by '-'.
         */
-        virtual Playlists::PlaylistPtr save( const Meta::TrackList &tracks,
-                                             const QString &name = QString() );
+        Playlists::PlaylistPtr save( const Meta::TrackList &tracks,
+                                             const QString &name = QString() ) override;
 
-        virtual bool import( const KUrl &path );
+        virtual bool import( const QUrl &path );
 
-        virtual bool isWritable() { return true; }
-        virtual void renamePlaylist( Playlists::PlaylistPtr playlist, const QString &newName );
-        virtual bool deletePlaylists( const Playlists::PlaylistList &playlists );
+        bool isWritable() override { return true; }
+        void renamePlaylist(Playlists::PlaylistPtr playlist, const QString &newName ) override;
+        bool deletePlaylists( const Playlists::PlaylistList &playlists ) override;
 
         /* PlaylistFileProvider methods */
         /** Schedules a PlaylistFile to be saved on the next iteration of the mainloop.
@@ -65,7 +67,7 @@ class PlaylistFileProvider : public Playlists::UserPlaylistProvider
           */
         void saveLater( Playlists::PlaylistFilePtr playlist );
 
-    private slots:
+    private Q_SLOTS:
         void loadPlaylists();
         void slotSaveLater();
 
@@ -74,7 +76,7 @@ class PlaylistFileProvider : public Playlists::UserPlaylistProvider
         KConfigGroup loadedPlaylistsConfig() const;
 
         bool m_playlistsLoaded;
-        QList<KUrl> m_urlsToLoad;
+        QList<QUrl> m_urlsToLoad;
         Playlists::PlaylistFileList m_playlists;
         QMultiMap<QString, Playlists::PlaylistPtr> m_groupMap;
 
