@@ -33,18 +33,15 @@
 #include <config.h> // for the compile flags
 #include "services/scriptable/ScriptableServiceManager.h"
 #include "ScriptItem.h"
-#include "ScriptUpdater.h"
 
-#include <KMessageBox>
-#include <KPluginInfo>
 #include <KPluginMetaData>
 
 #include <QFileInfo>
 #include <QJSEngine>
-#include <QJsonDocument>
 #include <QStandardPaths>
 #include <QTimer>
 #include <QDir>
+#include <QTemporaryFile>
 
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -56,7 +53,7 @@ ScriptManager::ScriptManager( QObject* parent )
     : QObject( parent )
 {
     DEBUG_BLOCK
-    setObjectName( "ScriptManager" );
+    setObjectName( QStringLiteral("ScriptManager") );
 
     s_instance = this;
 
@@ -114,28 +111,20 @@ QStringList
 ScriptManager::listRunningScripts() const
 {
     QStringList runningScripts;
-    foreach( const ScriptItem *item, m_scripts )
+    for( const ScriptItem *item : m_scripts )
     {
         if( item->running() )
-            runningScripts << item->info().pluginName();
+            runningScripts << item->info().pluginId();
     }
     return runningScripts;
 }
 
-QString
-ScriptManager::specForScript( const QString& name ) const
-{
-    if( !m_scripts.contains( name ) )
-        return QString();
-    return m_scripts[name]->specPath();
-}
-
 KPluginMetaData
-ScriptManager::createMetadaFromSpec( const QString &specPath )
+ScriptManager::createMetadataFromSpec( const QString &specPath )
 {
-    // KPluginMetaData and KPluginInfo require file suffix to be .desktop. Thus create temporary file with suffix
+    // KPluginMetaData requires file suffix to be .desktop. Thus create temporary file with suffix
     QFile specFile( specPath );
-    QTemporaryFile desktopFile( QDir::tempPath() + "/XXXXXX.desktop" );
+    QTemporaryFile desktopFile( QDir::tempPath() + QStringLiteral("/XXXXXX.desktop") );
 
     if ( !specFile.open( QIODevice::ReadOnly ) ) {
         warning() << "Could not read from spec file: " << specPath;
@@ -172,16 +161,13 @@ void
 ScriptManager::updateAllScripts() // SLOT
 {
     DEBUG_BLOCK
-    // Disable script updating for now. TODO review situation post 3.0
-    debug() << "Script updating hard disabled, not doing an update";
-    return;
 
     // find all scripts (both in $KDEHOME and /usr)
     QStringList foundScripts;
     QStringList locations = QStandardPaths::standardLocations( QStandardPaths::GenericDataLocation );
     for( const auto &location : locations )
     {
-        QDir dir( location + "/amarok/scripts" );
+        QDir dir( location + QStringLiteral("/amarok/scripts") );
 
         if( !dir.exists() )
             continue;
@@ -195,21 +181,22 @@ ScriptManager::updateAllScripts() // SLOT
     }
 
     // remove deleted scripts
-    foreach( ScriptItem *item, m_scripts )
+    const auto scripts = m_scripts;
+    for( ScriptItem *item : scripts )
     {
-        const QString specPath = QString( "%1/script.spec" ).arg( QFileInfo( item->url().path() ).path() );
+        const QString specPath = QStringLiteral( "%1/script.spec" ).arg( QFileInfo( item->url().path() ).path() );
         if( !QFile::exists( specPath ) )
         {
-            debug() << "Removing script " << item->info().pluginName();
+            debug() << "Removing script " << item->info().pluginId();
             item->uninstall();
-            m_scripts.remove( item->info().pluginName() );
+            m_scripts.remove( item->info().pluginId() );
         }
     }
 
     m_nScripts = foundScripts.count();
 
     // get timestamp of the last update check
-    KConfigGroup config = Amarok::config( "ScriptManager" );
+    KConfigGroup config = Amarok::config( QStringLiteral("ScriptManager") );
     const uint lastCheck = config.readEntry( "LastUpdateCheck", QVariant( 0 ) ).toUInt();
     const uint now = QDateTime::currentDateTimeUtc().toSecsSinceEpoch();
     bool autoUpdateScripts = AmarokConfig::autoUpdateScripts();
@@ -219,19 +206,20 @@ ScriptManager::updateAllScripts() // SLOT
     #endif
 
     // last update was at least 7 days ago -> check now if auto update is enabled
-    if( autoUpdateScripts && (now - lastCheck > 7*24*60*60) )
+    if( false && autoUpdateScripts && (now - lastCheck > 7*24*60*60) )
     {
+        // Disable script updating for now. TODO review situation post 3.0
         debug() << "ScriptUpdater: Performing script update check now!";
         for( int i = 0; i < m_nScripts; ++i )
         {
-            ScriptUpdater *updater = new ScriptUpdater( this );
+            /*ScriptUpdater *updater = new ScriptUpdater( this );
             // all the ScriptUpdaters are now started in parallel.
             // tell them which script to work on
             updater->setScriptPath( foundScripts.at( i ) );
             // tell them whom to signal when they're finished
             connect( updater, &ScriptUpdater::finished, this, &ScriptManager::updaterFinished );
             // and finally tell them to get to work
-            QTimer::singleShot( 0, updater, &ScriptUpdater::updateScript );
+            QTimer::singleShot( 0, updater, &ScriptUpdater::updateScript );*/
         }
         // store current timestamp
         config.writeEntry( "LastUpdateCheck", QVariant( now ) );
@@ -240,7 +228,7 @@ ScriptManager::updateAllScripts() // SLOT
     // last update was pretty recent, don't check again
     else
     {
-        debug() << "ScriptUpdater: Skipping update check";
+        debug() << "ScriptUpdater: Skipping update check - hard disabled";
         for ( int i = 0; i < m_nScripts; i++ )
         {
             loadScript( foundScripts.at( i ) );
@@ -273,7 +261,7 @@ ScriptManager::slotRunScript( const QString &name, bool silent )
     ScriptItem *item = m_scripts.value( name );
     connect( item, &ScriptItem::signalHandlerException,
              this, &ScriptManager::handleException );
-    if( item->info().category() == "Lyrics" )
+    if( item->info().category() == QStringLiteral("Lyrics") )
     {
         m_lyricsScript = name;
         debug() << "lyrics script started:" << name;
@@ -287,7 +275,7 @@ ScriptManager::handleException(const QJSValue& value)
 {
     DEBUG_BLOCK
 
-    Amarok::Logger::longMessage( i18n( "Script error reported by: %1\n%2", value.property("name").toString(), value.property("message").toString() ), Amarok::Logger::Error );
+    Amarok::Logger::longMessage( i18n( "Script error reported by: %1\n%2", value.property(QStringLiteral("name")).toString(), value.property(QStringLiteral("message")).toString() ), Amarok::Logger::Error );
 }
 
 void
@@ -329,11 +317,11 @@ ScriptManager::configChanged( bool changed )
 void
 ScriptManager::slotConfigChanged()
 {
-    foreach( ScriptItem *item, m_scripts )
+    for( ScriptItem *item : m_scripts )
     {
-        const QString name = item->info().pluginName();
-        bool enabledByDefault = item->info().isPluginEnabledByDefault();
-        bool enabled = Amarok::config( "Plugins" ).readEntry( name + "Enabled", enabledByDefault );
+        const QString name = item->info().pluginId();
+        bool enabledByDefault = item->info().isEnabledByDefault();
+        bool enabled = Amarok::config( QStringLiteral("Scripts") ).readEntry( name + QStringLiteral("Enabled"), enabledByDefault );
 
         if( !item->running() && enabled )
         {
@@ -356,8 +344,8 @@ ScriptManager::loadScript( const QString& path )
     //SupportAPIVersion << QLatin1String("API V1.0.0") << QLatin1String("API V1.0.1");
     QString ScriptVersion;
     QFileInfo info( path );
-    const QString jsonPath = QString( "%1/script.json" ).arg( info.path() );
-    const QString specPath = QString( "%1/script.spec" ).arg( info.path() );
+    const QString jsonPath = QStringLiteral( "%1/script.json" ).arg( info.path() );
+    const QString specPath = QStringLiteral( "%1/script.spec" ).arg( info.path() );
     KPluginMetaData pluginMetadata;
 
     if( QFile::exists( jsonPath ) )
@@ -367,7 +355,7 @@ ScriptManager::loadScript( const QString& path )
     else if( QFile::exists( specPath ) )
     {
         warning() << "Reading legacy spec file: " << specPath;
-        pluginMetadata = createMetadaFromSpec( specPath );
+        pluginMetadata = createMetadataFromSpec( specPath );
     }
     else
     {
@@ -391,18 +379,16 @@ ScriptManager::loadScript( const QString& path )
         return false;
     }
 
-    KPluginInfo pluginInfo( pluginMetadata );
-
     ScriptItem *item;
     if( !m_scripts.contains( pluginName ) )
     {
-        item = new ScriptItem( this, pluginName, path, pluginInfo );
+        item = new ScriptItem( this, pluginName, path, pluginMetadata );
         m_scripts[ pluginName ] = item;
     }
-    else if( m_scripts[pluginName]->info().version() < pluginInfo.version() )
+    else if( m_scripts[pluginName]->info().version() < pluginMetadata.version() )
     {
         m_scripts[ pluginName ]->deleteLater();
-        item = new ScriptItem( this, pluginName, path, pluginInfo );
+        item = new ScriptItem( this, pluginName, path, pluginMetadata );
         m_scripts[ pluginName ] = item;
     }
     else
@@ -424,11 +410,11 @@ ScriptManager::loadScript( const QString& path )
     return true;
 }
 
-KPluginInfo::List
+QVector<KPluginMetaData>
 ScriptManager::scripts( const QString &category ) const
 {
-    KPluginInfo::List scripts;
-    foreach( const ScriptItem *script, m_scripts )
+    QVector<KPluginMetaData> scripts;
+    for( const ScriptItem *script : m_scripts )
     {
         if( script->info().category() == category )
             scripts << script->info();
@@ -439,7 +425,7 @@ ScriptManager::scripts( const QString &category ) const
 QString
 ScriptManager::scriptNameForEngine( const QJSEngine *engine ) const
 {
-    foreach( const QString &name, m_scripts.keys() )
+    for( const QString &name : m_scripts.keys() )
     {
         ScriptItem *script = m_scripts[name];
         if( script->engine() == engine )
