@@ -137,9 +137,9 @@ GpodderProvider::possiblyContainsTrack( const QUrl &url ) const
 {
     DEBUG_BLOCK
 
-    foreach( PodcastChannelPtr ptr, m_channels )
+    for( PodcastChannelPtr ptr : m_channels )
     {
-        foreach( PodcastEpisodePtr episode, ptr->episodes() )
+        for( PodcastEpisodePtr episode : ptr->episodes() )
         {
             if( episode->uidUrl() == url.url() )
                 return true;
@@ -157,9 +157,9 @@ GpodderProvider::trackForUrl( const QUrl &url )
     if( url.isEmpty() )
         return Meta::TrackPtr();
 
-    foreach( PodcastChannelPtr podcast, m_channels )
+    for( PodcastChannelPtr podcast : m_channels )
     {
-        foreach( PodcastEpisodePtr episode, podcast->episodes() )
+        for( PodcastEpisodePtr episode : podcast->episodes() )
         {
             if( episode->uidUrl() == url.url() )
             {
@@ -174,9 +174,9 @@ GpodderProvider::trackForUrl( const QUrl &url )
 PodcastEpisodePtr
 GpodderProvider::episodeForGuid( const QString &guid )
 {
-    foreach( PodcastChannelPtr ptr, m_channels )
+    for( PodcastChannelPtr ptr : m_channels )
     {
-        foreach( PodcastEpisodePtr episode, ptr->episodes() )
+        for( PodcastEpisodePtr episode : ptr->episodes() )
         {
             if( episode->guid() == guid )
                 return episode;
@@ -205,12 +205,12 @@ GpodderProvider::addPlaylist( Playlists::PlaylistPtr playlist )
     PodcastChannelPtr master;
     PodcastChannelPtr slave;
 
-    foreach( PodcastChannelPtr tempChannel,
+    for( PodcastChannelPtr tempChannel :
              The::playlistManager()->defaultPodcasts()->channels() )
         if( tempChannel->url() == channel->url() )
             master = tempChannel;
 
-    foreach( PodcastChannelPtr tempChannel, this->channels() )
+    for( PodcastChannelPtr tempChannel : this->channels() )
         if( tempChannel->url() == channel->url() )
             slave = tempChannel;
 
@@ -251,7 +251,7 @@ GpodderProvider::addChannel( const PodcastChannelPtr &channel )
 
     m_channels << PodcastChannelPtr::dynamicCast( gpodderChannel );
 
-    emit playlistAdded( Playlists::PlaylistPtr::dynamicCast( gpodderChannel ) );
+    Q_EMIT playlistAdded( Playlists::PlaylistPtr::dynamicCast( gpodderChannel ) );
 
     return PodcastChannelPtr::dynamicCast( gpodderChannel );
 }
@@ -279,7 +279,7 @@ GpodderProvider::channels()
 
     PodcastChannelList list;
 
-    foreach( PodcastChannelPtr channel, m_channels )
+    for( PodcastChannelPtr channel : m_channels )
         list << PodcastChannelPtr::dynamicCast( channel );
 
     return list;
@@ -294,7 +294,7 @@ GpodderProvider::prettyName() const
 QIcon
 GpodderProvider::icon() const
 {
-    return QIcon::fromTheme( "view-services-gpodder-amarok" );
+    return QIcon::fromTheme( QStringLiteral("view-services-gpodder-amarok") );
 }
 
 Playlists::PlaylistList
@@ -302,7 +302,7 @@ GpodderProvider::playlists()
 {
     Playlists::PlaylistList playlists;
 
-    foreach( PodcastChannelPtr channel, m_channels )
+    for( PodcastChannelPtr channel : m_channels )
         playlists << Playlists::PlaylistPtr::staticCast( channel );
 
     return playlists;
@@ -328,7 +328,7 @@ GpodderProvider::removeChannel( const QUrl &url )
             m_uploadEpisodeStatusMap.remove( url );
             m_addList.removeAll( url );
 
-            emit playlistRemoved(
+            Q_EMIT playlistRemoved(
                         Playlists::PlaylistPtr::dynamicCast( channel ) );
 
             return;
@@ -345,9 +345,9 @@ GpodderProvider::channelActions( PodcastChannelList channels )
 
     if( m_removeAction == nullptr )
     {
-        m_removeAction = new QAction( QIcon::fromTheme( "edit-delete" ),
+        m_removeAction = new QAction( QIcon::fromTheme( QStringLiteral("edit-delete") ),
                 i18n( "&Delete Channel and Episodes" ), this );
-        m_removeAction->setProperty( "popupdropper_svg_id", "delete" );
+        m_removeAction->setProperty( "popupdropper_svg_id", QStringLiteral("delete") );
         connect( m_removeAction,  SIGNAL(triggered()), SLOT(slotRemoveChannels()) );
     }
     //Set the episode list as data that we'll retrieve in the slot
@@ -361,7 +361,7 @@ QActionList
 GpodderProvider::playlistActions( const Playlists::PlaylistList &playlists )
 {
     PodcastChannelList channels;
-    foreach( const Playlists::PlaylistPtr &playlist, playlists )
+    for( const Playlists::PlaylistPtr &playlist : playlists )
     {
         PodcastChannelPtr channel = PodcastChannelPtr::dynamicCast( playlist );
         if( channel )
@@ -384,7 +384,7 @@ GpodderProvider::slotRemoveChannels()
     PodcastChannelList channels = action->data().value<PodcastChannelList>();
     action->setData( QVariant() );      //Clear data
 
-    foreach( PodcastChannelPtr channel, channels )
+    for( PodcastChannelPtr channel : channels )
     {
         removeChannel( channel->url() );
 
@@ -400,7 +400,7 @@ GpodderProvider::slotSyncPlaylistAdded( Playlists::PlaylistPtr playlist )
     PodcastChannelPtr channel = Podcasts::PodcastChannelPtr::dynamicCast( playlist );
     //If the new channel already exist in gpodder channels, then
     //we don't have to add it to gpodder.net again
-    foreach( PodcastChannelPtr tempChannel, m_channels )
+    for( PodcastChannelPtr tempChannel : m_channels )
         if( channel->url() == tempChannel->url() )
             return;
 
@@ -414,7 +414,7 @@ GpodderProvider::slotSyncPlaylistRemoved( Playlists::PlaylistPtr playlist )
     Podcasts::PodcastChannelPtr channel = Podcasts::PodcastChannelPtr::dynamicCast( playlist );
     //If gpodder channels doesn't contains the removed channel from default
     //podcast provider, then we don't have to remove it from gpodder.net
-    foreach( PodcastChannelPtr tempChannel, m_channels )
+    for( PodcastChannelPtr tempChannel : m_channels )
         if( channel->url() == tempChannel->url() )
         {
             removeChannel( tempChannel->url() );
@@ -430,14 +430,14 @@ GpodderProvider::slotSyncPlaylistRemoved( Playlists::PlaylistPtr playlist )
 qulonglong
 GpodderProvider::subscriptionTimestamp()
 {
-    KConfigGroup config = Amarok::config( GpodderServiceConfig::configSectionName() );
+    KConfigGroup config = Amarok::config( QLatin1String(GpodderServiceConfig::configSectionName()) );
     return config.readEntry( "subscriptionTimestamp", 0 );
 }
 
 void
 GpodderProvider::setSubscriptionTimestamp( qulonglong newTimestamp )
 {
-    KConfigGroup config = Amarok::config( GpodderServiceConfig::configSectionName() );
+    KConfigGroup config = Amarok::config( QLatin1String(GpodderServiceConfig::configSectionName()) );
     config.writeEntry( "subscriptionTimestamp", newTimestamp );
 }
 
@@ -718,7 +718,7 @@ GpodderProvider::deviceUpdatesFinished()
     debug() << "DeviceUpdate timestamp: " << m_deviceUpdatesResult->timestamp();
 
     //Channels to subscribe locally
-    foreach( mygpo::PodcastPtr podcast, m_deviceUpdatesResult->addList() )
+    for( mygpo::PodcastPtr podcast : m_deviceUpdatesResult->addList() )
     {
         debug() << "Subscribing GPO channel: " << podcast->title() << ": " << podcast->url();
 
@@ -741,7 +741,7 @@ GpodderProvider::deviceUpdatesFinished()
 void
 GpodderProvider::continueDeviceUpdatesFinished()
 {
-    foreach( GpodderPodcastChannelPtr channel, m_resolvedChannelsToBeAdded )
+    for( GpodderPodcastChannelPtr channel : m_resolvedChannelsToBeAdded )
     {
         m_channelsToRequestActions.enqueue( channel->url() );
 
@@ -750,7 +750,7 @@ GpodderProvider::continueDeviceUpdatesFinished()
 
         slave = this->addChannel( PodcastChannelPtr::dynamicCast( channel ) );
 
-        foreach( PodcastChannelPtr tempChannel, The::playlistManager()->defaultPodcasts()->channels() )
+        for( PodcastChannelPtr tempChannel : The::playlistManager()->defaultPodcasts()->channels() )
             if( tempChannel->url() == channel->url() )
                 master = tempChannel;
 
@@ -828,11 +828,11 @@ GpodderProvider::episodeActionsInCascadeFinished()
 
     m_timestampStatus = m_episodeActionListResult->timestamp();
 
-    foreach( EpisodeActionPtr tempEpisodeAction, m_episodeActionListResult->list() )
+    for( EpisodeActionPtr tempEpisodeAction : m_episodeActionListResult->list() )
     {
         if( tempEpisodeAction->action() == EpisodeAction::Play )
         {
-            debug() << QString( "Adding a new play status to episode: %1" )
+            debug() << QStringLiteral( "Adding a new play status to episode: %1" )
                        .arg( tempEpisodeAction->episodeUrl().toString() );
 
             m_episodeStatusMap.insert( tempEpisodeAction->episodeUrl(), tempEpisodeAction );
@@ -846,12 +846,12 @@ GpodderProvider::episodeActionsInCascadeFinished()
             PodcastChannelPtr channel;
             PodcastEpisodePtr episode;
 
-            foreach( PodcastChannelPtr tempChannel, m_channels )
+            for( PodcastChannelPtr tempChannel : m_channels )
                 if( tempChannel->url() == tempEpisodeAction->podcastUrl() )
                 {
                     channel = tempChannel;
 
-                    foreach( PodcastEpisodePtr tempEpisode, channel->episodes() )
+                    for( PodcastEpisodePtr tempEpisode : channel->episodes() )
                         if( tempEpisode->uidUrl() == tempEpisodeAction->episodeUrl().toString() )
                             episode = tempEpisode;
                 }
@@ -862,7 +862,7 @@ GpodderProvider::episodeActionsInCascadeFinished()
                 {
                     if( !episode )
                     {
-                        debug() << QString( "New episode to be added found: %1" )
+                        debug() << QStringLiteral( "New episode to be added found: %1" )
                                    .arg( tempEpisodeAction->episodeUrl().toString() );
 
                         PodcastEpisodePtr tempEpisode;
@@ -874,7 +874,7 @@ GpodderProvider::episodeActionsInCascadeFinished()
                     }
                     else
                     {
-                        debug() << QString( "Marking an existent episode as new: %1" )
+                        debug() << QStringLiteral( "Marking an existent episode as new: %1" )
                                    .arg( tempEpisodeAction->episodeUrl().toString() );
 
                         episode->setNew( true );
@@ -882,13 +882,13 @@ GpodderProvider::episodeActionsInCascadeFinished()
                 }
                 else if( tempEpisodeAction->action() == EpisodeAction::Download )
                 {
-                    debug() << QString( "Adding a new download status to episode: %1" )
+                    debug() << QStringLiteral( "Adding a new download status to episode: %1" )
                                .arg( tempEpisodeAction->episodeUrl().toString() );
 
                 }
                 else if( tempEpisodeAction->action() == EpisodeAction::Delete )
                 {
-                    debug() << QString( "Adding a new delete status to episode: %1" )
+                    debug() << QStringLiteral( "Adding a new delete status to episode: %1" )
                                .arg( tempEpisodeAction->episodeUrl().toString() );
 
                 }
@@ -899,7 +899,7 @@ GpodderProvider::episodeActionsInCascadeFinished()
             {
                 //For some reason the podcast and/or episode for this action
                 //wasn't found
-                debug() << QString( "Episode and/or channel not found" );
+                debug() << QStringLiteral( "Episode and/or channel not found" );
             }
 
         }
@@ -944,13 +944,13 @@ GpodderProvider::updateLocalPodcasts( const QList<QPair<QUrl,QUrl> > updatedUrls
 
     for(; tempUpdatedUrl != updatedUrls.end(); ++tempUpdatedUrl )
     {
-        foreach( PodcastChannelPtr tempChannel, The::playlistManager()->defaultPodcasts()->channels() )
+        for( PodcastChannelPtr tempChannel : The::playlistManager()->defaultPodcasts()->channels() )
         {
             if( tempChannel->url() == (*tempUpdatedUrl).first )
                 tempChannel->setUrl( (*tempUpdatedUrl).second );
         }
 
-        foreach( PodcastChannelPtr tempGpodderChannel, m_channels )
+        for( PodcastChannelPtr tempGpodderChannel : m_channels )
         {
             if( tempGpodderChannel->url() == (*tempUpdatedUrl).first )
                 tempGpodderChannel->setUrl( (*tempUpdatedUrl).second );
@@ -1106,7 +1106,7 @@ void GpodderProvider::slotEpisodeMarkedAsNew( PodcastEpisodePtr episode )
 inline KConfigGroup
 GpodderProvider::gpodderActionsConfig() const
 {
-    return Amarok::config( "GPodder Cached Episode Actions" );
+    return Amarok::config( QStringLiteral("GPodder Cached Episode Actions") );
 }
 
 void GpodderProvider::loadCachedEpisodeActions()
@@ -1126,10 +1126,10 @@ void GpodderProvider::loadCachedEpisodeActions()
     QStringList actionsDetails;
     EpisodeAction::ActionType actionType;
 
-    foreach( QString episodeUrl, gpodderActionsConfig().keyList() )
+    for( const QString &episodeUrl : gpodderActionsConfig().keyList() )
     {
         actionsDetails.clear();
-        actionsDetails = gpodderActionsConfig().readEntry( episodeUrl ).split( ',' );
+        actionsDetails = gpodderActionsConfig().readEntry( episodeUrl ).split( QLatin1Char(',') );
 
         if( actionsDetails.count() != 6 )
             debug() << "There are less/more fields than expected.";
@@ -1161,7 +1161,7 @@ void GpodderProvider::loadCachedEpisodeActions()
                     debug() << "Action isn't a valid alternative.";
                 else
                 {
-                    debug() << QString( "Loaded %1 action." ).arg( episodeUrl );
+                    debug() << QStringLiteral( "Loaded %1 action." ).arg( episodeUrl );
 
                     EpisodeActionPtr tempEpisodeAction = EpisodeActionPtr(
                                 new EpisodeAction( QUrl( actionsDetails[0] ),
@@ -1198,7 +1198,7 @@ void GpodderProvider::saveCachedEpisodeActions()
     int actionType;
     QList<QString> actionsDetails;
 
-    foreach( EpisodeActionPtr action, m_uploadEpisodeStatusMap.values() )
+    for( EpisodeActionPtr action : m_uploadEpisodeStatusMap.values() )
     {
         actionsDetails.clear();
         actionsDetails.append( action->podcastUrl().toString() );
@@ -1225,7 +1225,7 @@ void GpodderProvider::saveCachedEpisodeActions()
 inline KConfigGroup
 GpodderProvider::gpodderPodcastsConfig() const
 {
-    return Amarok::config( "GPodder Cached Podcast Changes" );
+    return Amarok::config( QStringLiteral("GPodder Cached Podcast Changes") );
 }
 
 void GpodderProvider::loadCachedPodcastsChanges()
@@ -1238,19 +1238,19 @@ void GpodderProvider::loadCachedPodcastsChanges()
     QStringList podcastsUrlsToAdd;
     QStringList podcastsUrlsToRemove;
 
-    podcastsUrlsToAdd = gpodderPodcastsConfig().readEntry( "addList" ).split( ',' );
-    podcastsUrlsToRemove = gpodderPodcastsConfig().readEntry( "removeList" ).split( ',' );
+    podcastsUrlsToAdd = gpodderPodcastsConfig().readEntry( "addList" ).split( QLatin1Char(',') );
+    podcastsUrlsToRemove = gpodderPodcastsConfig().readEntry( "removeList" ).split( QLatin1Char(',') );
 
-    foreach( QString podcastUrl, podcastsUrlsToAdd )
+    for( QString podcastUrl : podcastsUrlsToAdd )
     {
-        debug() << QString( "New channel to subscribe: %1" ).arg( podcastUrl );
+        debug() << QStringLiteral( "New channel to subscribe: %1" ).arg( podcastUrl );
 
         m_addList.append( QUrl( podcastUrl ) );
     }
 
-    foreach( QString podcastUrl, podcastsUrlsToRemove )
+    for( QString podcastUrl : podcastsUrlsToRemove )
     {
-        debug() << QString( "New channel to unsubscribe: %1 action." ).arg( podcastUrl );
+        debug() << QStringLiteral( "New channel to unsubscribe: %1 action." ).arg( podcastUrl );
 
         m_removeList.append( QUrl( podcastUrl ) );
     }
@@ -1269,7 +1269,7 @@ void GpodderProvider::saveCachedPodcastsChanges()
     {
         QStringList podcastUrlsToAdd;
 
-        foreach( QUrl podcastUrl, m_addList )
+        for( QUrl podcastUrl : m_addList )
             podcastUrlsToAdd.append( podcastUrl.toString() );
 
         gpodderPodcastsConfig().writeEntry( "addList", podcastUrlsToAdd );
@@ -1279,7 +1279,7 @@ void GpodderProvider::saveCachedPodcastsChanges()
     {
         QStringList podcastsUrlsToRemove;
 
-        foreach( QUrl podcastUrl, m_removeList )
+        for( QUrl podcastUrl : m_removeList )
             podcastsUrlsToRemove.append( podcastUrl.toString() );
 
         gpodderPodcastsConfig().writeEntry( "removeList", podcastsUrlsToRemove );
