@@ -29,7 +29,6 @@
 
 #include <KLocalizedString>
 
-#include <QMenu>
 #include <QPainter>
 #include <QSize>
 #include <QSizePolicy>
@@ -41,7 +40,8 @@ BookmarkTriangle::BookmarkTriangle (QWidget *parent, int milliseconds, const QSt
     m_name ( name ),
     m_sliderwidth ( sliderwidth ),
     m_showPopup ( showPopup ),
-    m_tooltip ( nullptr )
+    m_tooltip ( nullptr ),
+    m_pos ( 0 )
 {
 }
 
@@ -75,7 +75,7 @@ int BookmarkTriangle::getTimeValue()
 void BookmarkTriangle::paintEvent ( QPaintEvent* )
 {
     QPainter p ( this );
-    p.drawPixmap ( 0, 0, The::svgHandler()->renderSvg ( "blue_triangle", 10 , 10, "blue_triangle" ) ); // TODO: This doesn't work
+    p.drawPixmap ( 0, 0, The::svgHandler()->renderSvg ( QStringLiteral("blue_triangle"), 10 , 10, QStringLiteral("blue_triangle") ) ); // TODO: This doesn't work
 }
 
 void BookmarkTriangle::showEvent ( QShowEvent * event )
@@ -144,10 +144,13 @@ void BookmarkTriangle::deleteBookmark ()
 
 }
 
-void BookmarkTriangle::enterEvent ( QEvent * event )
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+void BookmarkTriangle::enterEvent ( QEvent * )
+#else
+void BookmarkTriangle::enterEvent ( QEnterEvent * )
+#endif
 {
     DEBUG_BLOCK
-    Q_UNUSED ( event )
 
     Q_EMIT focused ( m_mseconds );
     initPopup();
